@@ -1,9 +1,12 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Kernel/GenericInterface/Mapping/Simple.pm - GenericInterface simple data mapping backend
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# --
+# $Id: Simple.pm,v 1.20 2011-05-03 11:26:02 mb Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::GenericInterface::Mapping::Simple;
@@ -13,15 +16,22 @@ use warnings;
 
 use Kernel::System::VariableCheck qw(IsHashRefWithData IsString IsStringWithData);
 
-our $ObjectManagerDisabled = 1;
+use vars qw(@ISA $VERSION);
+$VERSION = qw($Revision: 1.20 $) [1];
 
 =head1 NAME
 
 Kernel::GenericInterface::Mapping::Simple - GenericInterface simple data mapping backend
 
+=head1 SYNOPSIS
+
 =head1 PUBLIC INTERFACE
 
-=head2 new()
+=over 4
+
+=cut
+
+=item new()
 
 usually, you want to create an instance of this
 by using Kernel::GenericInterface::Mapping->new();
@@ -36,7 +46,7 @@ sub new {
     bless( $Self, $Type );
 
     # check needed params
-    for my $Needed (qw(DebuggerObject MappingConfig)) {
+    for my $Needed (qw(DebuggerObject MainObject MappingConfig)) {
         if ( !$Param{$Needed} ) {
             return {
                 Success      => 0,
@@ -71,10 +81,10 @@ sub new {
     return $Self;
 }
 
-=head2 Map()
+=item Map()
 
 provides 1:1 and regex mapping for keys and values
-also the use of a default for keys and values that were not mapped is possible
+also the use of a default for unmapped keys and values is possible
 
 we need the config to be in the following format
 
@@ -95,7 +105,7 @@ we need the config to be in the following format
                                    # 'MapTo' (use provided value as default)
             MapTo => 'new_value',  # only used if 'MapType' is 'MapTo'. then required
         },
-        ValueMap => {              # optional.
+        ValueMap => {
             'new_key_name' => {    # optional. Replacement for a specific key
                 ValueMapExact => { # optional. key/value pairs for direct replacement
                     'old_value'         => 'new_value',
@@ -138,9 +148,8 @@ sub Map {
 
     # check data - only accept undef or hash ref
     if ( defined $Param{Data} && ref $Param{Data} ne 'HASH' ) {
-        return $Self->{DebuggerObject}->Error(
-            Summary => 'Got Data but it is not a hash ref in Mapping Simple backend!'
-        );
+        return $Self->{DebuggerObject}
+            ->Error( Summary => 'Got Data but it is not a hash ref in Mapping Simple backend!' );
     }
 
     # return if data is empty
@@ -237,11 +246,7 @@ sub Map {
         }
 
         # check if we have a value mapping for the specific key
-        my $ValueMap;
-        if ( $Config->{ValueMap} && $Config->{ValueMap}->{$NewKey} ) {
-            $ValueMap = $Config->{ValueMap}->{$NewKey};
-        }
-
+        my $ValueMap = $Config->{ValueMap}->{$NewKey};
         if ($ValueMap) {
 
             # first check in exact (1:1) map
@@ -287,7 +292,7 @@ sub Map {
 
 =begin Internal:
 
-=head2 _ConfigCheck()
+=item _ConfigCheck()
 
 does checks to make sure the config is sane
 
@@ -411,50 +416,48 @@ sub _ConfigCheck {
     }
 
     # check ValueMap
-    if ( IsHashRefWithData( $Config->{ValueMap} ) ) {
-        for my $KeyName ( sort keys %{ $Config->{ValueMap} } ) {
+    for my $KeyName ( sort keys %{ $Config->{ValueMap} } ) {
 
-            # require values to be hash ref
-            if ( !IsHashRefWithData( $Config->{ValueMap}->{$KeyName} ) ) {
+        # require values to be hash ref
+        if ( !IsHashRefWithData( $Config->{ValueMap}->{$KeyName} ) ) {
+            return $Self->{DebuggerObject}->Error(
+                Summary => "Got $KeyName in ValueMap, but it is no hash ref with content!",
+            );
+        }
+
+        # possible subvalues are ValueMapExact or ValueMapRegEx and need to be hash ref if defined
+        SUBKEY:
+        for my $SubKeyName (qw(ValueMapExact ValueMapRegEx)) {
+            my $ValueMapType = $Config->{ValueMap}->{$KeyName}->{$SubKeyName};
+            next SUBKEY if !defined $ValueMapType;
+            if ( !IsHashRefWithData($ValueMapType) ) {
                 return $Self->{DebuggerObject}->Error(
-                    Summary => "Got $KeyName in ValueMap, but it is no hash ref with content!",
+                    Summary =>
+                        "Got $SubKeyName in $KeyName in ValueMap,"
+                        . ' but it is no hash ref with content!',
                 );
             }
 
-            # possible sub-values are ValueMapExact or ValueMapRegEx and need to be hash ref if defined
-            SUBKEY:
-            for my $SubKeyName (qw(ValueMapExact ValueMapRegEx)) {
-                my $ValueMapType = $Config->{ValueMap}->{$KeyName}->{$SubKeyName};
-                next SUBKEY if !defined $ValueMapType;
-                if ( !IsHashRefWithData($ValueMapType) ) {
+            # key/value pairs of ValueMapExact and ValueMapRegEx must be strings
+            for my $ValueMapTypeKey ( sort keys %{$ValueMapType} ) {
+                if ( !IsString($ValueMapTypeKey) ) {
                     return $Self->{DebuggerObject}->Error(
                         Summary =>
-                            "Got $SubKeyName in $KeyName in ValueMap,"
-                            . ' but it is no hash ref with content!',
+                            "Got key in $SubKeyName in $KeyName in ValueMap which is not a string!",
                     );
                 }
-
-                # key/value pairs of ValueMapExact and ValueMapRegEx must be strings
-                for my $ValueMapTypeKey ( sort keys %{$ValueMapType} ) {
-                    if ( !IsString($ValueMapTypeKey) ) {
-                        return $Self->{DebuggerObject}->Error(
-                            Summary =>
-                                "Got key in $SubKeyName in $KeyName in ValueMap which is not a string!",
-                        );
-                    }
-                    if ( !IsString( $ValueMapType->{$ValueMapTypeKey} ) ) {
-                        return $Self->{DebuggerObject}->Error(
-                            Summary =>
-                                "Got value for $ValueMapTypeKey in $SubKeyName in $KeyName in ValueMap"
-                                . ' which is not a string!',
-                        );
-                    }
+                if ( !IsString( $ValueMapType->{$ValueMapTypeKey} ) ) {
+                    return $Self->{DebuggerObject}->Error(
+                        Summary =>
+                            "Got value for $ValueMapTypeKey in $SubKeyName in $KeyName in ValueMap"
+                            . ' which is not a string!',
+                    );
                 }
             }
         }
     }
 
-    # if we arrive here, all checks were OK
+    # if we arrive here, all checks were ok
     return {
         Success => 1,
     };
@@ -464,12 +467,20 @@ sub _ConfigCheck {
 
 =end Internal:
 
+=back
+
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
+
+=cut
+
+=head1 VERSION
+
+$Revision: 1.20 $ $Date: 2011-05-03 11:26:02 $
 
 =cut
