@@ -1,9 +1,12 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Kernel/System/DB/mysql.pm - mysql database backend
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# --
+# $Id: mysql.pm,v 1.59 2011-08-12 09:06:16 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::DB::mysql;
@@ -11,15 +14,8 @@ package Kernel::System::DB::mysql;
 use strict;
 use warnings;
 
-use Encode ();
-
-our @ObjectDependencies = (
-    'Kernel::Config',
-    'Kernel::System::DateTime',
-    'Kernel::System::Encode',
-    'Kernel::System::Log',
-    'Kernel::System::Main',
-);
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.59 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -42,22 +38,9 @@ sub LoadPreferences {
     $Self->{'DB::QuoteSemicolon'}       = '\\';
     $Self->{'DB::QuoteUnderscoreStart'} = '\\';
     $Self->{'DB::QuoteUnderscoreEnd'}   = '';
-    $Self->{'DB::CaseSensitive'}        = 0;
+    $Self->{'DB::CaseInsensitive'}      = 1;
     $Self->{'DB::LikeEscapeString'}     = '';
 
-    # mysql needs to proprocess the data to fix UTF8 issues
-    $Self->{'DB::PreProcessSQL'}      = 1;
-    $Self->{'DB::PreProcessBindData'} = 1;
-
-    # how to determine server version
-    # version can have package prefix, we need to extract that
-    # example of VERSION() output: '5.5.32-0ubuntu0.12.04.1'
-    # if VERSION() contains 'MariaDB', add MariaDB, otherwise MySQL.
-    $Self->{'DB::Version'}
-        = "SELECT CONCAT( IF (INSTR( VERSION(),'MariaDB'),'MariaDB ','MySQL '), SUBSTRING_INDEX(VERSION(),'-',1))";
-
-    $Self->{'DB::ListTables'} = 'SHOW TABLES';
-
     # DBI/DBD::mysql attributes
     # disable automatic reconnects as they do not execute DB::Connect, which will
     # cause charset problems
@@ -78,57 +61,14 @@ sub LoadPreferences {
     #$Self->{'DB::ShellConnect'} = '';
 
     # init sql setting on db connect
-    if ( !$Kernel::OM->Get('Kernel::Config')->Get('Database::ShellOutput') ) {
+    if ( !$Self->{ConfigObject}->Get('Database::ShellOutput') )
+    {
         $Self->{'DB::Connect'} = 'SET NAMES utf8';
     }
 
     return 1;
 }
 
-sub PreProcessSQL {
-    my ( $Self, $SQLRef ) = @_;
-    $Self->_FixMysqlUTF8($SQLRef);
-    $Kernel::OM->Get('Kernel::System::Encode')->EncodeOutput($SQLRef);
-    return;
-}
-
-sub PreProcessBindData {
-    my ( $Self, $BindRef ) = @_;
-
-    my $Size = scalar @{ $BindRef // [] };
-
-    my $EncodeObject = $Kernel::OM->Get('Kernel::System::Encode');
-
-    for ( my $I = 0; $I < $Size; $I++ ) {
-
-        $Self->_FixMysqlUTF8( \$BindRef->[$I] );
-
-        # DBD::mysql 4.042+ requires data to be octets, so we encode the data on our own.
-        #   The mysql_enable_utf8 flag seems to be unusable because it treats ALL data as UTF8 unless
-        #   it has a custom bind data type like SQL_BLOB.
-        #
-        #   See also https://bugs.otrs.org/show_bug.cgi?id=12677.
-        $EncodeObject->EncodeOutput( \$BindRef->[$I] );
-    }
-    return;
-}
-
-# Replace any unicode characters that need more than three bytes in UTF8
-#   with the unicode replacement character. MySQL's utf8 encoding only
-#   supports three bytes. In future we might want to use utf8mb4 (supported
-#   since 5.5.3+), but that will lead to problems with key sizes on mysql.
-# See also http://mathiasbynens.be/notes/mysql-utf8mb4.
-sub _FixMysqlUTF8 {
-    my ( $Self, $StringRef ) = @_;
-
-    return if !$$StringRef;
-    return if !Encode::is_utf8($$StringRef);
-
-    $$StringRef =~ s/([\x{10000}-\x{10FFFF}])/"\x{FFFD}"/eg;
-
-    return;
-}
-
 sub Quote {
     my ( $Self, $Text, $Type ) = @_;
 
@@ -157,10 +97,7 @@ sub DatabaseCreate {
 
     # check needed stuff
     if ( !$Param{Name} ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'error',
-            Message  => 'Need Name!'
-        );
+        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need Name!' );
         return;
     }
 
@@ -173,10 +110,7 @@ sub DatabaseDrop {
 
     # check needed stuff
     if ( !$Param{Name} ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'error',
-            Message  => 'Need Name!'
-        );
+        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need Name!' );
         return;
     }
 
@@ -187,9 +121,6 @@ sub DatabaseDrop {
 sub TableCreate {
     my ( $Self, @Param ) = @_;
 
-    # get config object
-    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
-
     my $SQLStart     = '';
     my $SQLEnd       = '';
     my $SQL          = '';
@@ -203,7 +134,6 @@ sub TableCreate {
     my %Uniq         = ();
     my $PrimaryKey   = '';
     my @Return       = ();
-
     for my $Tag (@Param) {
 
         if (
@@ -211,7 +141,7 @@ sub TableCreate {
             && $Tag->{TagType} eq 'Start'
             )
         {
-            if ( $ConfigObject->Get('Database::ShellOutput') ) {
+            if ( $Self->{ConfigObject}->Get('Database::ShellOutput') ) {
                 $SQLStart .= $Self->{'DB::Comment'}
                     . "----------------------------------------------------------\n";
                 $SQLStart .= $Self->{'DB::Comment'} . " create table $Tag->{Name}\n";
@@ -337,17 +267,35 @@ sub TableCreate {
     $SQL .= "\n";
     push @Return, $SQLStart . $SQL . $SQLEnd;
 
+    # add indexs
+    #    for my $Name (sort keys %Index) {
+    #        push (@Return, $Self->IndexCreate(
+    #            TableName => $TableName,
+    #            Name => $Name,
+    #            Data => $Index{$Name},
+    #        ));
+    #    }
+    # add uniq
+    #    for my $Name (sort keys %Uniq) {
+    #        push (@Return, $Self->UniqueCreate(
+    #            TableName => $TableName,
+    #            Name => $Name,
+    #            Data => $Uniq{$Name},
+    #        ));
+    #    }
     # add foreign keys
     for my $ForeignKey ( sort keys %Foreign ) {
         my @Array = @{ $Foreign{$ForeignKey} };
         for ( 0 .. $#Array ) {
-            push @{ $Self->{Post} },
+            push(
+                @{ $Self->{Post} },
                 $Self->ForeignKeyCreate(
-                LocalTableName   => $TableName,
-                Local            => $Array[$_]->{Local},
-                ForeignTableName => $ForeignKey,
-                Foreign          => $Array[$_]->{Foreign},
-                );
+                    LocalTableName   => $TableName,
+                    Local            => $Array[$_]->{Local},
+                    ForeignTableName => $ForeignKey,
+                    Foreign          => $Array[$_]->{Foreign},
+                ),
+            );
         }
     }
     return @Return;
@@ -356,13 +304,10 @@ sub TableCreate {
 sub TableDrop {
     my ( $Self, @Param ) = @_;
 
-    # get config object
-    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
-
     my $SQL = '';
     for my $Tag (@Param) {
         if ( $Tag->{Tag} eq 'Table' && $Tag->{TagType} eq 'Start' ) {
-            if ( $ConfigObject->Get('Database::ShellOutput') ) {
+            if ( $Self->{ConfigObject}->Get('Database::ShellOutput') ) {
                 $SQL .= $Self->{'DB::Comment'}
                     . "----------------------------------------------------------\n";
                 $SQL .= $Self->{'DB::Comment'} . " drop table $Tag->{Name}\n";
@@ -379,9 +324,6 @@ sub TableDrop {
 sub TableAlter {
     my ( $Self, @Param ) = @_;
 
-    # get config object
-    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
-
     my $SQLStart      = '';
     my @SQL           = ();
     my @Index         = ();
@@ -390,12 +332,11 @@ sub TableAlter {
     my $ReferenceName = '';
     my @Reference     = ();
     my $Table         = '';
-
     for my $Tag (@Param) {
 
         if ( $Tag->{Tag} eq 'TableAlter' && $Tag->{TagType} eq 'Start' ) {
             $Table = $Tag->{Name} || $Tag->{NameNew};
-            if ( $ConfigObject->Get('Database::ShellOutput') ) {
+            if ( $Self->{ConfigObject}->Get('Database::ShellOutput') ) {
                 $SQLStart .= $Self->{'DB::Comment'}
                     . "----------------------------------------------------------\n";
                 $SQLStart .= $Self->{'DB::Comment'} . " alter table $Table\n";
@@ -461,9 +402,9 @@ sub TableAlter {
             # normal data type
             push @SQL, $SQLStart . " CHANGE $Tag->{NameOld} $Tag->{NameNew} $Tag->{Type} NULL";
 
-            # set default as NULL (not on TEXT/BLOB/LONGBLOB type, not supported by mysql)
-            if ( $Tag->{Type} !~ /^(TEXT|MEDIUMTEXT|BLOB|LONGBLOB)$/i ) {
-                push @SQL, "ALTER TABLE $Table CHANGE $Tag->{NameNew} $Tag->{NameNew} $Tag->{Type} DEFAULT NULL";
+            # remove possible default (not on TEXT/BLOB/LONGBLOB type, not supported by mysql)
+            if ( $Tag->{Type} !~ /^(TEXT|BLOB|LONGBLOB)$/i ) {
+                push @SQL, "ALTER TABLE $Table ALTER $Tag->{NameNew} DROP DEFAULT";
             }
 
             # investigate the default value
@@ -485,7 +426,8 @@ sub TableAlter {
                 push @SQL,
                     "UPDATE $Table SET $Tag->{NameNew} = $Default WHERE $Tag->{NameNew} IS NULL";
 
-                my $SQLAlter = "ALTER TABLE $Table CHANGE $Tag->{NameNew} $Tag->{NameNew} $Tag->{Type}";
+                my $SQLAlter
+                    = "ALTER TABLE $Table CHANGE $Tag->{NameNew} $Tag->{NameNew} $Tag->{Type}";
 
                 # add default
                 if ( defined $Tag->{Default} ) {
@@ -557,39 +499,27 @@ sub IndexCreate {
     # check needed stuff
     for (qw(TableName Name Data)) {
         if ( !$Param{$_} ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
-                Priority => 'error',
-                Message  => "Need $_!"
-            );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
             return;
         }
     }
 
-    my $CreateIndexSQL = "CREATE INDEX $Param{Name} ON $Param{TableName} (";
-    my @Array          = @{ $Param{Data} };
+    my $SQL   = "CREATE INDEX $Param{Name} ON $Param{TableName} (";
+    my @Array = @{ $Param{Data} };
     for ( 0 .. $#Array ) {
         if ( $_ > 0 ) {
-            $CreateIndexSQL .= ', ';
+            $SQL .= ', ';
         }
-        $CreateIndexSQL .= $Array[$_]->{Name};
+        $SQL .= $Array[$_]->{Name};
         if ( $Array[$_]->{Size} ) {
-            $CreateIndexSQL .= "($Array[$_]->{Size})";
+            $SQL .= "($Array[$_]->{Size})";
         }
     }
-    $CreateIndexSQL .= ')';
-
-    my @SQL;
-
-    # create index only if it does not exist already
-    push @SQL,
-        "SET \@IndexExists := (SELECT COUNT(*) FROM information_schema.statistics WHERE table_schema = DATABASE() AND table_name = '$Param{TableName}' AND index_name = '$Param{Name}')";
-    push @SQL,
-        "SET \@IndexSQLStatement := IF( \@IndexExists = 0, '$CreateIndexSQL', 'SELECT ''INFO: Index $Param{Name} already exists, skipping.''' )";
-    push @SQL, "PREPARE IndexStatement FROM \@IndexSQLStatement";
-    push @SQL, "EXECUTE IndexStatement";
+    $SQL .= ')';
 
     # return SQL
-    return @SQL;
+    return ($SQL);
+
 }
 
 sub IndexDrop {
@@ -598,28 +528,12 @@ sub IndexDrop {
     # check needed stuff
     for (qw(TableName Name)) {
         if ( !$Param{$_} ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
-                Priority => 'error',
-                Message  => "Need $_!",
-            );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
             return;
         }
     }
-
-    my $DropIndexSQL = 'DROP INDEX ' . $Param{Name} . ' ON ' . $Param{TableName};
-
-    my @SQL;
-
-    # drop index only if it does still exist
-    push @SQL,
-        "SET \@IndexExists := (SELECT COUNT(*) FROM information_schema.statistics WHERE table_schema = DATABASE() AND table_name = '$Param{TableName}' AND index_name = '$Param{Name}')";
-    push @SQL,
-        "SET \@IndexSQLStatement := IF( \@IndexExists > 0, '$DropIndexSQL', 'SELECT ''INFO: Index $Param{Name} does not exist, skipping.''' )";
-    push @SQL, "PREPARE IndexStatement FROM \@IndexSQLStatement";
-    push @SQL, "EXECUTE IndexStatement";
-
-    # return SQL
-    return @SQL;
+    my $SQL = 'DROP INDEX ' . $Param{Name} . ' ON ' . $Param{TableName};
+    return ($SQL);
 }
 
 sub ForeignKeyCreate {
@@ -628,10 +542,7 @@ sub ForeignKeyCreate {
     # check needed stuff
     for (qw(LocalTableName Local ForeignTableName Foreign)) {
         if ( !$Param{$_} ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
-                Priority => 'error',
-                Message  => "Need $_!"
-            );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
             return;
         }
     }
@@ -639,29 +550,19 @@ sub ForeignKeyCreate {
     # create foreign key name
     my $ForeignKey = "FK_$Param{LocalTableName}_$Param{Local}_$Param{Foreign}";
     if ( length($ForeignKey) > 60 ) {
-        my $MD5 = $Kernel::OM->Get('Kernel::System::Main')->MD5sum(
+        my $MD5 = $Self->{MainObject}->MD5sum(
             String => $ForeignKey,
         );
         $ForeignKey = substr $ForeignKey, 0, 58;
         $ForeignKey .= substr $MD5, 0,  1;
-        $ForeignKey .= substr $MD5, 31, 1;
+        $ForeignKey .= substr $MD5, 61, 1;
     }
 
     # add foreign key
-    my $CreateForeignKeySQL = "ALTER TABLE $Param{LocalTableName} ADD CONSTRAINT $ForeignKey FOREIGN KEY "
+    my $SQL = "ALTER TABLE $Param{LocalTableName} ADD CONSTRAINT $ForeignKey FOREIGN KEY "
         . "($Param{Local}) REFERENCES $Param{ForeignTableName} ($Param{Foreign})";
 
-    my @SQL;
-
-    # create foreign key
-    push @SQL,
-        "SET \@FKExists := (SELECT COUNT(*) FROM information_schema.table_constraints WHERE table_schema = DATABASE() AND table_name = '$Param{LocalTableName}' AND constraint_name = '$ForeignKey')";
-    push @SQL,
-        "SET \@FKSQLStatement := IF( \@FKExists = 0, '$CreateForeignKeySQL', 'SELECT ''INFO: Foreign key constraint $ForeignKey does already exist, skipping.''' )";
-    push @SQL, "PREPARE FKStatement FROM \@FKSQLStatement";
-    push @SQL, "EXECUTE FKStatement";
-
-    return @SQL;
+    return ($SQL);
 }
 
 sub ForeignKeyDrop {
@@ -670,10 +571,7 @@ sub ForeignKeyDrop {
     # check needed stuff
     for (qw(LocalTableName Local ForeignTableName Foreign)) {
         if ( !$Param{$_} ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
-                Priority => 'error',
-                Message  => "Need $_!"
-            );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
             return;
         }
     }
@@ -681,39 +579,18 @@ sub ForeignKeyDrop {
     # create foreign key name
     my $ForeignKey = "FK_$Param{LocalTableName}_$Param{Local}_$Param{Foreign}";
     if ( length($ForeignKey) > 60 ) {
-        my $MD5 = $Kernel::OM->Get('Kernel::System::Main')->MD5sum(
+        my $MD5 = $Self->{MainObject}->MD5sum(
             String => $ForeignKey,
         );
         $ForeignKey = substr $ForeignKey, 0, 58;
         $ForeignKey .= substr $MD5, 0,  1;
-        $ForeignKey .= substr $MD5, 31, 1;
-    }
-
-    my @SQL;
-    if ( $Kernel::OM->Get('Kernel::Config')->Get('Database::ShellOutput') ) {
-        push @SQL, $Self->{'DB::Comment'}
-            . ' MySQL does not create foreign key constraints in MyISAM. Dropping nonexisting constraints in MyISAM works just fine.';
-        push @SQL, $Self->{'DB::Comment'}
-            . ' However, if the table is converted to InnoDB, this will result in an error. Therefore, only drop constraints if they exist.';
+        $ForeignKey .= substr $MD5, 61, 1;
     }
 
     # drop foreign key
-    push @SQL,
-        "SET \@FKExists := (SELECT COUNT(*) FROM information_schema.table_constraints WHERE table_schema = DATABASE() AND table_name = '$Param{LocalTableName}' AND constraint_name = '$ForeignKey')";
-    push @SQL,
-        "SET \@FKSQLStatement := IF( \@FKExists > 0, 'ALTER TABLE $Param{LocalTableName} DROP FOREIGN KEY $ForeignKey', 'SELECT ''INFO: Foreign key constraint $ForeignKey does not exist, skipping.''' )";
-    push @SQL, "PREPARE FKStatement FROM \@FKSQLStatement";
-    push @SQL, "EXECUTE FKStatement";
+    my $SQL = "ALTER TABLE $Param{LocalTableName} DROP FOREIGN KEY $ForeignKey";
 
-    # drop index with the same name like the foreign key
-    push @SQL,
-        "SET \@IndexExists := (SELECT COUNT(*) FROM information_schema.statistics WHERE table_schema = DATABASE() AND table_name = '$Param{LocalTableName}' AND index_name = '$ForeignKey')";
-    push @SQL,
-        "SET \@IndexSQLStatement := IF( \@IndexExists > 0, 'DROP INDEX $ForeignKey ON $Param{LocalTableName}', 'SELECT ''INFO: Index $ForeignKey does not exist, skipping.''' )";
-    push @SQL, "PREPARE IndexStatement FROM \@IndexSQLStatement";
-    push @SQL, "EXECUTE IndexStatement";
-
-    return @SQL;
+    return ($SQL);
 }
 
 sub UniqueCreate {
@@ -722,34 +599,23 @@ sub UniqueCreate {
     # check needed stuff
     for (qw(TableName Name Data)) {
         if ( !$Param{$_} ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
-                Priority => 'error',
-                Message  => "Need $_!"
-            );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
             return;
         }
     }
-    my $CreateUniqueSQL = "ALTER TABLE $Param{TableName} ADD CONSTRAINT $Param{Name} UNIQUE INDEX (";
-    my @Array           = @{ $Param{Data} };
+    my $SQL   = "ALTER TABLE $Param{TableName} ADD CONSTRAINT $Param{Name} UNIQUE INDEX (";
+    my @Array = @{ $Param{Data} };
     for ( 0 .. $#Array ) {
         if ( $_ > 0 ) {
-            $CreateUniqueSQL .= ', ';
+            $SQL .= ', ';
         }
-        $CreateUniqueSQL .= $Array[$_]->{Name};
+        $SQL .= $Array[$_]->{Name};
     }
-    $CreateUniqueSQL .= ')';
+    $SQL .= ')';
 
-    my @SQL;
+    # return SQL
+    return ($SQL);
 
-    # create unique constraint
-    push @SQL,
-        "SET \@UniqueExists := (SELECT COUNT(*) FROM information_schema.table_constraints WHERE table_schema = DATABASE() AND table_name = '$Param{TableName}' AND constraint_name = '$Param{Name}')";
-    push @SQL,
-        "SET \@UniqueSQLStatement := IF( \@UniqueExists = 0, '$CreateUniqueSQL', 'SELECT ''INFO: Unique constraint $Param{Name} does already exist, skipping.''' )";
-    push @SQL, "PREPARE UniqueStatement FROM \@UniqueSQLStatement";
-    push @SQL, "EXECUTE UniqueStatement";
-
-    return @SQL;
 }
 
 sub UniqueDrop {
@@ -758,41 +624,23 @@ sub UniqueDrop {
     # check needed stuff
     for (qw(TableName Name)) {
         if ( !$Param{$_} ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
-                Priority => 'error',
-                Message  => "Need $_!"
-            );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
             return;
         }
     }
-    my $DropUniqueSQL = 'ALTER TABLE ' . $Param{TableName} . ' DROP INDEX ' . $Param{Name};
-
-    my @SQL;
-
-    # create unique constraint
-    push @SQL,
-        "SET \@UniqueExists := (SELECT COUNT(*) FROM information_schema.table_constraints WHERE table_schema = DATABASE() AND table_name = '$Param{TableName}' AND constraint_name = '$Param{Name}')";
-    push @SQL,
-        "SET \@UniqueSQLStatement := IF( \@UniqueExists > 0, '$DropUniqueSQL', 'SELECT ''INFO: Unique constraint $Param{Name} does not exist, skipping.''' )";
-    push @SQL, "PREPARE UniqueStatement FROM \@UniqueSQLStatement";
-    push @SQL, "EXECUTE UniqueStatement";
-
-    return @SQL;
+    my $SQL = 'ALTER TABLE ' . $Param{TableName} . ' DROP INDEX ' . $Param{Name};
+    return ($SQL);
 }
 
 sub Insert {
     my ( $Self, @Param ) = @_;
 
-    # get needed objects
-    my $ConfigObject   = $Kernel::OM->Get('Kernel::Config');
-    my $DateTimeObject = $Kernel::OM->Create('Kernel::System::DateTime');
-
     my $SQL    = '';
     my @Keys   = ();
     my @Values = ();
     for my $Tag (@Param) {
         if ( $Tag->{Tag} eq 'Insert' && $Tag->{TagType} eq 'Start' ) {
-            if ( $ConfigObject->Get('Database::ShellOutput') ) {
+            if ( $Self->{ConfigObject}->Get('Database::ShellOutput') ) {
                 $SQL .= $Self->{'DB::Comment'}
                     . "----------------------------------------------------------\n";
                 $SQL .= $Self->{'DB::Comment'} . " insert into table $Tag->{Table}\n";
@@ -807,7 +655,7 @@ sub Insert {
             my $Value;
             if ( defined $Tag->{Value} ) {
                 $Value = $Tag->{Value};
-                $Kernel::OM->Get('Kernel::System::Log')->Log(
+                $Self->{LogObject}->Log(
                     Priority => 'error',
                     Message  => 'The content for inserts is not longer appreciated '
                         . 'attribut Value, use Content from now on! Reason: You can\'t '
@@ -842,15 +690,18 @@ sub Insert {
             $Value .= ', ';
         }
         if ( $Tmp eq 'current_timestamp' ) {
-            if ( $ConfigObject->Get('Database::ShellOutput') ) {
+            if ( $Self->{ConfigObject}->Get('Database::ShellOutput') ) {
                 $Value .= $Tmp;
             }
             else {
-                my $Timestamp = $DateTimeObject->ToString();
+                my $Timestamp = $Self->{TimeObject}->CurrentTimestamp();
                 $Value .= '\'' . $Timestamp . '\'';
             }
         }
         else {
+            if ( $Self->{ConfigObject}->Get('Database::ShellOutput') ) {
+                $Tmp =~ s/\n/\r/g;
+            }
             $Value .= $Tmp;
         }
     }
