@@ -1,9 +1,12 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Kernel/System/ReferenceData.pm - Provides reference data to OTRS
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
+# --
+# $Id: ReferenceData.pm,v 1.2.2.1 2012-05-29 07:04:53 mb Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::ReferenceData;
@@ -13,27 +16,53 @@ use warnings;
 
 use Locale::Country qw(all_country_names);
 
-our @ObjectDependencies = (
-    'Kernel::Config',
-    'Kernel::System::Log',
-);
+use vars qw(@ISA $VERSION);
+$VERSION = qw($Revision: 1.2.2.1 $) [1];
 
 =head1 NAME
 
 Kernel::System::ReferenceData - ReferenceData lib
 
-=head1 DESCRIPTION
+=head1 SYNOPSIS
 
 Contains reference data. For now, this is limited to just a list of ISO country
 codes.
 
 =head1 PUBLIC INTERFACE
 
-=head2 new()
+=over 4
 
-Don't use the constructor directly, use the ObjectManager instead:
+=cut
 
-    my $ReferenceDataObject = $Kernel::OM->Get('Kernel::System::ReferenceData');
+=item new()
+
+create an object
+
+    use Kernel::Config;
+    use Kernel::System::Encode;
+    use Kernel::System::Log;
+    use Kernel::System::Main;
+    use Kernel::System::ReferenceData;
+
+    my $ConfigObject = Kernel::Config->new();
+    my $EncodeObject = Kernel::System::Encode->new(
+        ConfigObject => $ConfigObject,
+    );
+    my $LogObject = Kernel::System::Log->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+    );
+    my $MainObject = Kernel::System::Main->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+        LogObject    => $LogObject,
+    );
+    my $ReferenceDataObject = Kernel::System::ReferenceData->new(
+        ConfigObject => $ConfigObject,
+        LogObject    => $LogObject,
+        EncodeObject => $EncodeObject,
+        MainObject   => $MainObject,
+    );
 
 =cut
 
@@ -44,10 +73,15 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
+    # check needed objects
+    for my $Object (qw(ConfigObject LogObject EncodeObject MainObject)) {
+        $Self->{$Object} = $Param{$Object} || die "Got no $Object!";
+    }
+
     return $Self;
 }
 
-=head2 CountryList()
+=item CountryList()
 
 return a list of countries as a hash reference. The countries are based on ISO
 3166-2 and are provided by the Perl module Locale::Code::Country, or optionally
@@ -66,7 +100,7 @@ sub CountryList {
         $Param{Result} = undef;
     }
 
-    my $Countries = $Kernel::OM->Get('Kernel::Config')->Get('ReferenceData::OwnCountryList');
+    my $Countries = $Self->{ConfigObject}->Get('ReferenceData::OwnCountryList');
 
     if ( $Param{Result} && $Countries ) {
 
@@ -82,13 +116,6 @@ sub CountryList {
 
     my @CountryNames = all_country_names();
 
-    if ( !@CountryNames ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'error',
-            Message  => 'Country name list is empty!',
-        );
-    }
-
     if ( $Param{Result} ) {
 
         # return Code => Country pairs from ISO list
@@ -107,12 +134,20 @@ sub CountryList {
 
 1;
 
+=back
+
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
+
+=cut
+
+=head1 VERSION
+
+$Revision: 1.2.2.1 $ $Date: 2012-05-29 07:04:53 $
 
 =cut
