@@ -1,6 +1,9 @@
-#!/usr/bin/perl
+#!/usr/bin/perl -w
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# bin/otrs.AddGroup.pl - add new system groups
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# --
+# $Id: otrs.AddGroup.pl,v 1.5 2011-11-03 21:00:04 mb Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -9,12 +12,12 @@
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
@@ -24,8 +27,6 @@ use warnings;
 use File::Basename;
 use FindBin qw($RealBin);
 use lib dirname($RealBin);
-use lib dirname($RealBin) . '/Kernel/cpan-lib';
-use lib dirname($RealBin) . '/Custom';
 
 use Kernel::Config;
 use Kernel::System::Encode;
@@ -34,6 +35,21 @@ use Kernel::System::DB;
 use Kernel::System::Group;
 use Kernel::System::Main;
 
+my %opts;
+
+use Getopt::Std;
+getopts( 'c:n:h', \%opts );
+
+if ( $opts{h} ) {
+    print STDERR "Usage: $0 [-c <comment>] -n <groupname>\n";
+    exit;
+}
+
+if ( !$opts{n} ) {
+    print STDERR "ERROR: Need -n groupname\n";
+    exit 1;
+}
+
 # create common objects
 my %CommonObject;
 $CommonObject{ConfigObject} = Kernel::Config->new();
@@ -46,32 +62,17 @@ $CommonObject{MainObject}  = Kernel::System::Main->new(%CommonObject);
 $CommonObject{DBObject}    = Kernel::System::DB->new(%CommonObject);
 $CommonObject{GroupObject} = Kernel::System::Group->new(%CommonObject);
 
-my %Options;
-
-use Getopt::Std;
-getopts( 'c:n:h', \%Options );
-
-if ( $Options{h} ) {
-    print STDERR "Usage: $0 [-c <comment>] -n <groupname>\n";
-    exit;
-}
-
-if ( !$Options{n} ) {
-    print STDERR "ERROR: Need -n groupname\n";
-    exit 1;
-}
-
 # user id of the person adding the record
 my %Param;
 $Param{UserID} = '1';
 
 # Validrecord
 $Param{ValidID} = '1';
-$Param{Comment} = $Options{c} || '';
-$Param{Name}    = $Options{n} || '';
+$Param{Comment} = $opts{c} || '';
+$Param{Name}    = $opts{n} || '';
 
 if ( my $GID = $CommonObject{GroupObject}->GroupAdd(%Param) ) {
-    print "Group '$Options{n}' added. Group id is '$GID'\n";
+    print "Group '$opts{n}' added. Group id is '$GID'\n";
 }
 else {
     print STDERR "ERROR: Can't add group\n";
